@@ -7,4 +7,8 @@ from myLabTools import cnki
 from myLabTools import t2s
 from myLabTools import translate
 from myLabTools import sciie
-__version__ = "0.5.8.1"
+from myLabTools import decorators
+from myLabTools import spider
+from myLabTools import web_app
+
+__version__ = "0.6.1.7"
