@@ -1,11 +1,15 @@
 from .langconv import *
-
+"""将sentence中的繁体字转为简体字
+"""
 def Traditional2Simplified(sentence):
-    '''
-    将sentence中的繁体字转为简体字
-    :param sentence: 待转换的句子
-    :return: 将句子中繁体字转换为简体字之后的句子
-    '''
+    """将sentence中的繁体字转为简体字
+
+    Args:
+        sentence (_type_): 待转换的句子
+
+    Returns:
+        _type_: 将句子中繁体字转换为简体字之后的句子
+    """    
     sentence = Converter('zh-hans').convert(sentence)
     return sentence
 
